@@ -1,47 +1,9 @@
-/****************************************************************************
-**
-** Copyright (C) 2021 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtPositioning module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2021 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qgeopositioninfosourcefactory_nmea.h"
 #include <QtPositioning/QNmeaPositionInfoSource>
 #include <QtPositioning/QNmeaSatelliteInfoSource>
-#include <QtSerialPort/QSerialPort>
-#include <QtSerialPort/QSerialPortInfo>
 #include <QtNetwork/QTcpSocket>
 #include <QLoggingCategory>
 #include <QSet>
@@ -50,6 +12,12 @@
 #include <QSharedPointer>
 #include "qiopipe_p.h"
 
+#ifdef QT_NMEA_PLUGIN_HAS_SERIALPORT
+#  include <QtSerialPort/QSerialPort>
+#  include <QtSerialPort/QSerialPortInfo>
+#endif
+
+
 Q_LOGGING_CATEGORY(lcNmea, "qt.positioning.nmea")
 
 QT_BEGIN_NAMESPACE
@@ -58,6 +26,8 @@ static const auto sourceParameterName = QStringLiteral("nmea.source");
 static const auto socketScheme = QStringLiteral("socket:");
 static const auto serialScheme = QStringLiteral("serial:");
 
+#ifdef QT_NMEA_PLUGIN_HAS_SERIALPORT
+
 // This class is used only for SerialPort devices, because we can't open the
 // same serial port twice.
 // In case of files and sockets it's easier to explicitly create a QIODevice for
@@ -131,6 +101,8 @@ private:
 
 Q_GLOBAL_STATIC(IODeviceContainer, deviceContainer)
 
+#endif // QT_NMEA_PLUGIN_HAS_SERIALPORT
+
 // We use a string prefix to distinguish between the different data sources.
 // "socket:" means that we use a socket connection
 // "serial:" means that we use a serial port connection
@@ -181,7 +153,10 @@ NmeaSource::NmeaSource(QObject *parent, const QString &fileName)
 
 NmeaSource::~NmeaSource()
 {
-    deviceContainer->releaseSerial(m_sourceName, m_dataSource);
+#ifdef QT_NMEA_PLUGIN_HAS_SERIALPORT
+    if (deviceContainer.exists())
+        deviceContainer->releaseSerial(m_sourceName, m_dataSource);
+#endif
 }
 
 void NmeaSource::onSocketError(QAbstractSocket::SocketError error)
@@ -218,12 +193,13 @@ void NmeaSource::parseSourceParameter(const QString &source)
     }
 }
 
+#ifdef QT_NMEA_PLUGIN_HAS_SERIALPORT
 static QString tryFindSerialDevice(const QString &requestedPort)
 {
     QString portName;
     if (requestedPort.isEmpty()) {
         const QList<QSerialPortInfo> ports = QSerialPortInfo::availablePorts();
-        qCDebug(lcNmea) << "Found" << ports.count() << "serial ports";
+        qCDebug(lcNmea) << "Found" << ports.size() << "serial ports";
         if (ports.isEmpty()) {
             qWarning("nmea: No serial ports found");
             return portName;
@@ -250,9 +226,11 @@ static QString tryFindSerialDevice(const QString &requestedPort)
     }
     return portName;
 }
+#endif // QT_NMEA_PLUGIN_HAS_SERIALPORT
 
 void NmeaSource::addSerialDevice(const QString &requestedPort)
 {
+#ifdef QT_NMEA_PLUGIN_HAS_SERIALPORT
     m_sourceName = tryFindSerialDevice(requestedPort);
     if (m_sourceName.isEmpty())
         return;
@@ -262,6 +240,12 @@ void NmeaSource::addSerialDevice(const QString &requestedPort)
         return;
 
     setDevice(m_dataSource.data());
+#else
+    // As we are not calling setDevice(), the source will be invalid, so
+    // the factory methods will return nullptr.
+    qWarning() << "Plugin was built without serialport support!"
+               << requestedPort << "cannot be used!";
+#endif
 }
 
 void NmeaSource::setFileName(const QString &fileName)
@@ -349,7 +333,10 @@ NmeaSatelliteSource::NmeaSatelliteSource(QObject *parent, const QString &fileNam
 
 NmeaSatelliteSource::~NmeaSatelliteSource()
 {
-    deviceContainer->releaseSerial(m_sourceName, m_port);
+#ifdef QT_NMEA_PLUGIN_HAS_SERIALPORT
+    if (deviceContainer.exists())
+        deviceContainer->releaseSerial(m_sourceName, m_port);
+#endif
 }
 
 void NmeaSatelliteSource::onSocketError(QAbstractSocket::SocketError error)
@@ -394,6 +381,7 @@ void NmeaSatelliteSource::parseRealtimeSource(const QString &source)
             qWarning("nmea: incorrect socket parameters %s:%d", qPrintable(host), port);
         }
     } else {
+#ifdef QT_NMEA_PLUGIN_HAS_SERIALPORT
         // Last chance - this can be serial device.
         m_sourceName = tryFindSerialDevice(source);
         if (m_sourceName.isEmpty())
@@ -404,6 +392,12 @@ void NmeaSatelliteSource::parseRealtimeSource(const QString &source)
             return;
 
         setDevice(m_port.data());
+#else
+        // As we are not calling setDevice(), the source will be invalid, so
+        // the factory methods will return nullptr.
+        qWarning() << "Plugin was built without serialport support!"
+                   << source << "cannot be used!";
+#endif // QT_NMEA_PLUGIN_HAS_SERIALPORT
     }
 }
 
